CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
107 lines
3.1 KiB
C++
107 lines
3.1 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <utils.hh>
|
|
|
|
HIP_TEST_CASE(Unit_hipHostGetDevicePointer_Negative) {
|
|
int* hPtr{nullptr};
|
|
int* dPtr{nullptr};
|
|
HIP_CHECK(hipHostMalloc(&hPtr, sizeof(int)));
|
|
|
|
if (!DeviceAttributesSupport(0, hipDeviceAttributeCanMapHostMemory)) {
|
|
HIP_CHECK_ERROR(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), hPtr, 0),
|
|
hipErrorNotSupported);
|
|
return;
|
|
}
|
|
|
|
SECTION("Nullptr as device") {
|
|
HIP_CHECK_ERROR(hipHostGetDevicePointer(nullptr, hPtr, 0), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("Nullptr as host") {
|
|
int* dPtr{nullptr};
|
|
HIP_CHECK_ERROR(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), nullptr, 0),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("Non pinned memory as host") {
|
|
int* hPtr = reinterpret_cast<int*>(malloc(sizeof(*hPtr)));
|
|
HIP_CHECK_ERROR(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), hPtr, 0),
|
|
hipErrorInvalidValue);
|
|
free(hPtr);
|
|
}
|
|
|
|
SECTION("Flags non-zero") {
|
|
HIP_CHECK_ERROR(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), hPtr, 1),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
HIP_CHECK(hipHostFree(hPtr));
|
|
}
|
|
|
|
template <typename T> __global__ void set(T* ptr, T val) { *ptr = val; }
|
|
|
|
HIP_TEST_CASE(Unit_hipHostGetDevicePointer_UseCase) {
|
|
if (!DeviceAttributesSupport(0, hipDeviceAttributeCanMapHostMemory)) {
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kHostPinnedMemoryUnsupported);
|
|
}
|
|
|
|
int* hPtr{nullptr};
|
|
HIP_CHECK(hipHostMalloc(&hPtr, sizeof(int)));
|
|
|
|
auto kernel = set<int>;
|
|
constexpr int value = 10;
|
|
|
|
SECTION("Set the value on device - Get device ptr") {
|
|
int* dPtr{nullptr};
|
|
HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), hPtr, 0));
|
|
REQUIRE(dPtr != nullptr);
|
|
|
|
kernel<<<1, 1>>>(dPtr, value);
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
REQUIRE(*hPtr == value);
|
|
}
|
|
|
|
SECTION("Set the value on device - by hipHostRegister") {
|
|
int res{0}; // Stuff on stack
|
|
HIP_CHECK(hipHostRegister(&res, sizeof(int), 0)); // Lets map stack memory :)
|
|
|
|
int* dPtr{nullptr};
|
|
HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&dPtr), &res, 0))
|
|
|
|
kernel<<<1, 1>>>(dPtr, value);
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
HIP_CHECK(hipHostUnregister(&res));
|
|
|
|
REQUIRE(res == value);
|
|
}
|
|
|
|
HIP_CHECK(hipHostFree(hPtr));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipHostGetDevicePointer_Capture) {
|
|
if (!DeviceAttributesSupport(0, hipDeviceAttributeCanMapHostMemory)) {
|
|
HIP_SKIP_TEST(HipTest::SkipReason::kHostPinnedMemoryUnsupported);
|
|
}
|
|
|
|
int* host_ptr = nullptr;
|
|
int* device_ptr = nullptr;
|
|
HIP_CHECK(hipHostMalloc(&host_ptr, sizeof(int)));
|
|
|
|
hipStream_t stream = nullptr;
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
|
|
GENERATE_CAPTURE();
|
|
BEGIN_CAPTURE(stream);
|
|
HIP_CHECK(hipHostGetDevicePointer(reinterpret_cast<void**>(&device_ptr), host_ptr, 0));
|
|
END_CAPTURE(stream);
|
|
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
HIP_CHECK(hipHostFree(host_ptr));
|
|
}
|